summaryrefslogtreecommitdiff
path: root/src/intel/vulkan/anv_private.h
diff options
context:
space:
mode:
authorJason Ekstrand <jason.ekstrand@intel.com>2018-06-26 09:35:35 -0700
committerJason Ekstrand <jason.ekstrand@intel.com>2019-01-14 10:16:52 -0600
commitc92c449361632ce9ea83698ea91bd1b8149dd745 (patch)
tree3d2e0471bddc9b7ceb11f037cf10a79c3c44d780 /src/intel/vulkan/anv_private.h
parent4bd976e3b8b796353ce577fd543803d74886303e (diff)
anv: Rename has_resolve to has_color_resolve
Diffstat (limited to 'src/intel/vulkan/anv_private.h')
-rw-r--r--src/intel/vulkan/anv_private.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/intel/vulkan/anv_private.h b/src/intel/vulkan/anv_private.h
index 770254e93ea..15d693eee47 100644
--- a/src/intel/vulkan/anv_private.h
+++ b/src/intel/vulkan/anv_private.h
@@ -3229,8 +3229,8 @@ struct anv_subpass {
/** Subpass has a depth/stencil self-dependency */
bool has_ds_self_dep;
- /** Subpass has at least one resolve attachment */
- bool has_resolve;
+ /** Subpass has at least one color resolve attachment */
+ bool has_color_resolve;
};
static inline unsigned